@@ -26,7 +26,7 @@
 #include <libxml/parser.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtktreemodel.h>
-#include <glade/glade.h>
+#include <gtk/gtkbuilder.h>
 
 #include <libsoup/soup-xmlrpc-message.h>
 
@@ -55,11 +55,13 @@ typedef struct {
 	char *name;
 	char *cname;
 	char *comment;
-	GdkPixbuf *pixbuf;
+	char *icon;
 	char *bugzilla;
 	char *product;
 	char *component;
 	char *version;
+	char *extra_info_script;
+	int   ref_count; 
 } BugzillaApplication;
 
 struct _GnomeVersionInfo {
@@ -77,11 +79,12 @@ int                bugzilla_parse_response (SoupMessage *msg,
 gboolean	   bugzilla_search_for_package (gpointer key, gpointer value, const char *package);
 
 SoupXmlrpcMessage* bugzilla_create_report  (BugzillaApplication *app, 
+					    int type,
                                             GnomeVersionInfo *gnome_version,
                                             const char *username,
                                             const char *title,
                                             const char *text,
-                                            GladeXML *xml,
+                                            GtkBuilder *ui,
                                             GError **err);
 
 #endif /* __BUGZILLA_H__ */
